@@ -110,6 +110,7 @@ class SwaggerUIPlugin(BasePlugin):
             iframe_filename = f"swagger-{cur_id}.html"
             iframe_id_list.append(cur_id)
             cur_options = self.process_options(swagger_ui_ele)
+            cur_oath2_prop = self.process_oath2_prop(swagger_ui_ele)
 
             openapi_spec_url = self.path_to_url(page.file,
                                                 swagger_ui_ele.get('src', ""))
@@ -119,7 +120,8 @@ class SwaggerUIPlugin(BasePlugin):
                 background=self.config['background'],
                 id=cur_id,
                 openapi_spec_url=openapi_spec_url,
-                options=json.dumps(cur_options, indent=4)[1:-1])
+                options=json.dumps(cur_options, indent=4)[1:-1],
+                oath2_prop=json.dumps(cur_oath2_prop))
             with open(os.path.join(page_dir, iframe_filename), 'w') as f:
                 f.write(output_from_parsed_template)
             self.replace_with_iframe(soup, swagger_ui_ele, cur_id,
@@ -139,13 +141,15 @@ class SwaggerUIPlugin(BasePlugin):
 
             # only use options from first grouped swagger ui tag
             cur_options = self.process_options(grouped_list[0])
+            cur_oath2_prop = self.process_oath2_prop(grouped_list[0])
             output_from_parsed_template = template.render(
                 css_dir=css_dir,
                 js_dir=js_dir,
                 background=self.config['background'],
                 id=cur_id,
                 openapi_spec_url=openapi_spec_url,
-                options=json.dumps(cur_options, indent=4)[1:-1])
+                options=json.dumps(cur_options, indent=4)[1:-1],
+                oath2_prop=json.dumps(cur_oath2_prop))
             with open(os.path.join(page_dir, iframe_filename), 'w') as f:
                 f.write(output_from_parsed_template)
             self.replace_with_iframe(soup, grouped_list[0], cur_id,
@@ -154,54 +158,55 @@ class SwaggerUIPlugin(BasePlugin):
             for rest_swagger_ui_ele in grouped_list[1:]:
                 rest_swagger_ui_ele.extract()
 
-        if swagger_ui_list:
-            js_code = soup.new_tag("script")
-            js_code["type"] = "text/javascript"
-            js_code.string = """
-                update_swagger_ui_iframe_height = function (id) {
-                    var iFrameID = document.getElementById(id);
-                    if (iFrameID) {
-                        full_height = (iFrameID.contentWindow.document.body.scrollHeight + 80) + "px";
-                        iFrameID.height = full_height;
-                        iFrameID.style.height = full_height;
-                    }
+        js_code = soup.new_tag("script")
+        # trigger from iframe body ResizeObserver
+        js_code.string = """
+            window.update_swagger_ui_iframe_height = function (id) {
+                var iFrameID = document.getElementById(id);
+                if (iFrameID) {
+                    full_height = (iFrameID.contentWindow.document.body.scrollHeight + 80) + "px";
+                    iFrameID.height = full_height;
+                    iFrameID.style.height = full_height;
                 }
-                var scheme = document.body.getAttribute("data-md-color-scheme")
-                const options = {
-                    childList: true,
-                    attributes: true,
-                    characterData: false,
-                    subtree: false,
-                    attributeFilter: ['data-md-color-scheme'],
-                    attributeOldValue: false,
-                    characterDataOldValue: false
-                };
-            """
-            js_code.string += f"""
-                const iframe_id_list = {json.dumps(iframe_id_list)}
-            """
+            }
+        """
+        if config["theme"].name == "material":
+            # synchronized dark mode with mkdocs-material
             js_code.string += """
-                function color_scheme_callback(mutations) {
-                    for (let mutation of mutations) {
-                        if (mutation.attributeName === "data-md-color-scheme") {
-                            scheme = document.body.getAttribute("data-md-color-scheme")
-                            iframe_id_list.forEach((id) => {
-                                var ele = document.getElementById(id);
-                                if (ele) {
-                                    if (scheme === "slate") {
-                                        ele.contentWindow.enable_dark_mode();
-                                    } else {
-                                        ele.contentWindow.disable_dark_mode();
-                                    }
+            window.scheme = document.body.getAttribute("data-md-color-scheme")
+            const options = {
+                childList: true,
+                attributes: true,
+                characterData: false,
+                subtree: false,
+                attributeFilter: ['data-md-color-scheme'],
+                attributeOldValue: false,
+                characterDataOldValue: false
+            };
+            function color_scheme_callback(mutations) {
+                for (let mutation of mutations) {
+                    if (mutation.attributeName === "data-md-color-scheme") {
+                        scheme = document.body.getAttribute("data-md-color-scheme")
+                        var iframe_list = document.getElementsByClassName("swagger-ui-iframe")
+                        for(var i = 0; i < iframe_list.length; i++) {
+                            var ele = iframe_list.item(i);
+                            if (ele) {
+                                if (scheme === "slate") {
+                                    ele.contentWindow.enable_dark_mode();
+                                } else {
+                                    ele.contentWindow.disable_dark_mode();
                                 }
-                            })
+                            }
                         }
                     }
                 }
-                observer = new MutationObserver(color_scheme_callback);
-                observer.observe(document.body, options);
+            }
+            observer = new MutationObserver(color_scheme_callback);
+            observer.observe(document.body, options);
             """
-            soup.body.append(js_code)
+            # support compatible with mkdocs-material Instant loading feature
+            js_code.string = "document$.subscribe(() => {" + js_code.string + "})"
+        soup.body.append(js_code)
 
         return str(soup)
 
@@ -214,6 +219,7 @@ class SwaggerUIPlugin(BasePlugin):
         iframe['frameborder'] = "0"
         iframe['style'] = "overflow:hidden;width:100%;"
         iframe['width'] = "100%"
+        iframe['class'] = "swagger-ui-iframe"
         swagger_ui_ele.replaceWith(iframe)
 
     def process_options(self, swagger_ui_ele):
@@ -225,18 +231,22 @@ class SwaggerUIPlugin(BasePlugin):
         options_keys = global_options.keys()
         cur_options = {}
         for k in options_keys:
-            cur_val = swagger_ui_ele.get(k.lower(), None)
-            if cur_val is not None:
+            val = swagger_ui_ele.get(k.lower(), None)
+            if val is not None:
                 if k == "supportedSubmitMethods":
                     try:
-                        cur_val = json.loads(cur_val.replace("'", '"'))
-                        if not isinstance(cur_val, list):
+                        val = json.loads(val.replace("'", '"'))
+                        if not isinstance(val, list):
                             raise ValueError(
-                                f"attribute supportedSubmitMethods: {cur_val} is not a list."
+                                f"Attribute supportedSubmitMethods: {val} is not a list."
                             )
-                    except:
-                        cur_val = global_options['supportedSubmitMethods']
-                cur_options[k] = cur_val
+                        cur_options[k] = val
+                    except Exception as e:
+                        logging.error(e)
+                        logging.error(
+                            "Ignore supportedSubmitMethods attribute setting.")
+                else:
+                    cur_options[k] = val
             else:
                 cur_options[k] = global_options[k]
             if cur_options[k] is None:
@@ -246,6 +256,44 @@ class SwaggerUIPlugin(BasePlugin):
                 "syntaxHighlightTheme")
         return cur_options
 
+    def process_oath2_prop(self, swagger_ui_ele):
+        """ Retrieve Swagger UI OAuth 2.0 configuration from tag attributes """
+        oath_prop_keys = [
+            "clientId",
+            "clientSecret",
+            "realm",
+            "appName",
+            "scopes",
+            "additionalQueryStringParams",
+            "useBasicAuthenticationWithAccessCodeGrant",
+            "usePkceWithAuthorizationCodeGrant",
+        ]
+        cur_prop = {}
+        for k in oath_prop_keys:
+            val = swagger_ui_ele.get(k.lower(), None)
+            if val is not None:
+                if k == "additionalQueryStringParams":
+                    try:
+                        val = json.loads(val.replace("'", '"'))
+                        if not isinstance(val, dict):
+                            raise ValueError(
+                                f"attribute additionalQueryStringParams: {val} is not a dict."
+                            )
+                        cur_prop[k] = val
+                    except Exception as e:
+                        logging.error(e)
+                        logging.error(
+                            "Ignore additionalQueryStringParams attribute setting."
+                        )
+                elif k in [
+                        "useBasicAuthenticationWithAccessCodeGrant",
+                        "usePkceWithAuthorizationCodeGrant"
+                ]:
+                    cur_prop[k] = val.lower().strip() == "true"
+                else:
+                    cur_prop[k] = val
+        return cur_prop
+
     def on_post_build(self, config, **kwargs):
         """ Copy Swagger UI css and js files to assets directory """
 
